@@ -11,24 +11,37 @@ use crate::numbers::*;
 use arrayvec;
 use arrayvec::{Array, ArrayVec};
 use std;
-use std::ops::*;
 
 /// Buffer borrow type for `SingleBuffer`.
 pub struct FixedLenBufferBurrow<'a, T: RealNumber + 'a> {
     data: &'a mut [T],
 }
 
-impl<'a, T: RealNumber> Deref for FixedLenBufferBurrow<'a, T> {
-    type Target = [T];
+impl<'a, T: RealNumber + 'a> ToSlice<T> for FixedLenBufferBurrow<'a, T> {
+    fn to_slice(&self) -> &[T] {
+        self.data.to_slice()
+    }
 
-    fn deref(&self) -> &[T] {
-        self.data
+    fn len(&self) -> usize {
+        self.data.len()
+    }
+
+    fn is_empty(&self) -> bool {
+        self.data.is_empty()
+    }
+
+    fn alloc_len(&self) -> usize {
+        self.data.alloc_len()
+    }
+
+    fn try_resize(&mut self, len: usize) -> VoidResult {
+        self.data.try_resize(len)
     }
 }
 
-impl<'a, T: RealNumber> DerefMut for FixedLenBufferBurrow<'a, T> {
-    fn deref_mut(&mut self) -> &mut [T] {
-        self.data
+impl<'a, T: RealNumber + 'a> ToSliceMut<T> for FixedLenBufferBurrow<'a, T>  {
+    fn to_slice_mut(&mut self) -> &mut [T] {
+        self.data.to_slice_mut()
     }
 }
 
